@@ -463,31 +463,85 @@ int ScriptCompiler::compile(const char *scrname)
 Script::Name *ScriptCompiler::include(const char *token)
 {
 	char buffer[256];
+	const char *local = cmds->getLast("binclude");
 	const char *prefix = cmds->getLast("include");
 	const char *cp;
-	Name *inc;
+	Name *inc = getScript(token);
+
+	if(inc)
+		return inc;
 
 	if(!prefix)
 		return NULL;
 
 	snprintf(buffer, sizeof(buffer), "virtual.%s", token);
 	cp = cmds->getLast(buffer);
-	if(cp)
-		snprintf(buffer, sizeof(buffer), "%s/%s_%s.mac", prefix, token, cp);
-	else
-		snprintf(buffer, sizeof(buffer), "%s/%s.mac", prefix, token);
 
-	inc = getScript(token);
-	if(!inc)
+	if(local)
 	{
-		if(!isFile(buffer))
+                if(cp)
+                        snprintf(buffer, sizeof(buffer),
+                                "%s/%s_%s.mac", local, token, cp);
+                else
+                        snprintf(buffer, sizeof(buffer),
+                                "%s/%s.mac", local, token);
+		if(!isFile(buffer) || !canAccess(buffer))
+			local = NULL;
+        }
+
+	if(!local)
+	{
+		if(cp)
+			snprintf(buffer, sizeof(buffer), 
+				"%s/%s_%s.mac", prefix, token, cp);
+		else
+			snprintf(buffer, sizeof(buffer), 
+				"%s/%s.mac", prefix, token);
+		if(!isFile(buffer) || !canAccess(buffer))
 			return NULL;
-		if(!canAccess(buffer))
-			return NULL;
-		compile(buffer, (char *)token);
-		inc = getScript(token);
 	}
-	return inc;
+
+	compile(buffer, (char *)token);
+	return getScript(token);
+}
+
+int ScriptCompiler::compileDefinitions(const char *filename)
+{
+	char buffer[128];
+	int rtn;
+
+	const char *cp = strrchr(filename, '.');
+	if(!cp || stricmp(cp, ".def"))
+		return 0;
+
+	cp = strrchr(cp, '/');
+#ifdef	WIN32
+	if(!cp)
+		cp = strrchr(cp, '\\');
+	if(!cp)
+		cp = strchr(cp, ':');
+#endif
+
+	if(!cp)
+	{
+		snprintf(buffer, sizeof(buffer), "%s/%s",
+			cmds->getLast("include"), filename);
+		filename = buffer;
+	}
+
+	if(!isFile(filename) || !canAccess(filename))
+		return 0;
+
+	scrSource.open(filename);
+	if(!scrSource.is_open())
+		return 0;
+
+	Script::use_definitions = true;
+
+	rtn = compile((istream *)&scrSource, "definitions", filename);
+	scrSource.close();
+	scrSource.clear();
+	return rtn;
 }
 
 int ScriptCompiler::compile(const char *scrname, char *name)
@@ -526,7 +580,7 @@ int ScriptCompiler::compile(istream *str, char *name, const char *scrname)
 	unsigned short count, number, total = 0;
 	size_t gvarlen;
 	NamedEvent *events, *esave;
-	Name *script;
+	Name *script, *ds;
 	Line *line, *last;
 	unsigned long addmask, submask, trapmask, mask, cmask = 0;
 	Method handler;
@@ -594,11 +648,11 @@ int ScriptCompiler::compile(istream *str, char *name, const char *scrname)
 
 	if(cp && !stricmp(cp, ".def"))
 	{
-		ripple = true;
+		ripple = false;
 		defs = true;
 	}
 
-	if(bm)
+	if(bm || defs)
 		access = scrPROTECTED;
 
 	gvarname[0] = '%';
@@ -648,7 +702,7 @@ compile:
 
         key = Script::getIndex(csname);
 
-	if(first && bm)
+	if(first && (bm || defs))
 		initkey = SCRIPT_INDEX_SIZE;
 	else if(first)
 		initkey = key;
@@ -873,7 +927,6 @@ repname1:
                                 pmode = "function";
                                 goto repname1;
                         }
-                             
 
                         if(!stricmp(token, "local") && !ripple && !embed && !apps && !strchr(token, ':'))
                         {
@@ -909,7 +962,7 @@ repname1:
 
 			if((ripple || apps) && *token == '[')
 			{
-				if(use_funcs || defs)
+				if(use_funcs)
 					pmode = "function";
 				else
 					pmode = "public";
@@ -1005,6 +1058,11 @@ noexec:
 		{
 			if(NULL != (token = getToken()))
 			{
+				snprintf(temp, sizeof(temp), "use.%s", token);
+				cp = (char *)cmds->getLast(temp);
+				if(cp)
+					token = cp;
+
 				if(!Script::use(token))
 					slog.warn("%s(%d): %s: package missing", filename, lnum, token);
 			}
@@ -1130,7 +1188,8 @@ noexec:
 		{
 			pretoken = token;
 			token = "call";
-		} else
+		} 
+		else
 			pretoken = NULL;
 
 		if(*token == '@')
@@ -1141,6 +1200,17 @@ noexec:
 
 		trapflag = false;
 		handler = cmds->getHandler(token);
+		if(handler == (Method)NULL && use_definitions)
+		{
+			snprintf(temp, sizeof(temp), "definitions::%s", token);
+			ds = getScript(temp);
+			if(ds && ds->access == scrFUNCTION)
+			{
+				pretoken = alloc(temp);
+				token = "call";
+				handler = cmds->getHandler(token);
+			}
+		}
 		if(handler == (Method)NULL)
 		{
 			errmsg = preproc(token);
