@@ -237,6 +237,9 @@ bool ScriptInterp::setConst(const char *id, const char *value)
 
 	len = (unsigned short)strlen(value);
 
+	if(!len)
+		++len;
+
 	sym = mapSymbol(id, len);
 
 	if(!sym)
@@ -1145,6 +1148,17 @@ void ScriptInterp::enterThread(ScriptThread *thr)
 {
 }
 
+bool ScriptInterp::eventThread(const char *evt, bool flag)
+{
+	if(updated)
+		return false;
+
+	if(scriptEvent(evt, flag))
+		updated = true;
+
+	return updated;
+}
+
 void ScriptInterp::exitThread(const char *msg)
 {
 	if(updated)
@@ -1403,6 +1417,7 @@ const char *ScriptInterp::getContent(const char *opt)
 	char *tmp;
 	Array *a;
 	ScriptProperty *p;
+	long v;
 
 	if(!opt)
 		return NULL;
@@ -1440,9 +1455,20 @@ const char *ScriptInterp::getContent(const char *opt)
 			snprintf(tmp, 11, "%d", strlen(sym->data));
 			return tmp;
 		case symCOUNTER:
-		case symTIMER:
 			snprintf(tmp, 11, "%ld", atol(sym->data));
 			return tmp;
+		case symTIMER:
+			if(!sym->data[0])
+			{
+				setString(tmp, 11, "999999999");
+				return tmp;
+			}
+			v = atol(extract(sym));
+			if(v < 0)
+				snprintf(tmp, 11, "%ld", -v);
+			else
+				setString(tmp, 11, "0");
+			return tmp;
 		case symINITIAL:
 			return "0";
 		case symPROPERTY:
