@@ -779,7 +779,8 @@ bool ScriptMethods::scrThrow(void)
 		return true;
 	}
 
-	scriptEvent(++cp);
+	if(!scriptEvent(++cp))
+		advance();
 	return true;
 }
 
